@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "file.h"
 
 #include <config-ktorrent.h>
@@ -32,7 +18,7 @@
 namespace bt
 {
 File::File()
-    : fptr(0)
+    : fptr(nullptr)
 {
 }
 
@@ -52,14 +38,14 @@ bool File::open(const QString &file, const QString &mode)
 #else
     fptr = fopen(QFile::encodeName(file).constData(), mode.toUtf8().constData());
 #endif
-    return fptr != 0;
+    return fptr != nullptr;
 }
 
 void File::close()
 {
     if (fptr) {
         fclose(fptr);
-        fptr = 0;
+        fptr = nullptr;
     }
 }
 
